==> erpc-1.5.0.tar.gz: erpc-1.5.0/setup.py <==
#!/usr/bin/env python

# The Clear BSD License
# Copyright (c) 2016 Freescale Semiconductor, Inc.
# Copyright 2016 NXP
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification,
# are permitted (subject to the limitations in the disclaimer below) provided
# that the following conditions are met:
#
# o Redistributions of source code must retain the above copyright notice, this list
#   of conditions and the following disclaimer.
#
# o Redistributions in binary form must reproduce the above copyright notice, this
#   list of conditions and the following disclaimer in the documentation and/or
#   other materials provided with the distribution.
#
# o Neither the name of the copyright holder nor the names of its
#   contributors may be used to endorse or promote products derived from this
#   software without specific prior written permission.
#
# NO EXPRESS OR IMPLIED LICENSES TO ANY PARTY'S PATENT RIGHTS ARE GRANTED BY THIS LICENSE.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
# ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
# ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

from setuptools import setup
from erpc import erpc_version
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

#steps: https://packaging.python.org/distributing/
#source distribution: python setup.py sdist
#wheel distribution: python setup.py bdist_wheel
#web: https://pypi.python.org/pypi?%3Aaction=submit_form

setup(
    name="erpc",
    version=erpc_version.ERPC_VERSION,
    description="eRPC Python infrastructure",
    long_description=long_description,
    author="NXP",
    url='https://github.com/embeddedrpc/erpc',
    license="BSD 3-Clause",
    install_requires=["enum34","pyserial"],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved :: BSD License",
        "Programming Language :: Python",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Embedded Systems",
        "Natural Language :: English",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: POSIX :: Linux",
    ],
    keywords='rpc rpc-framework embedded multicore multiprocessor amp',
    use_2to3=True,
    packages=['erpc'],
)

==> erpc-1.9.1.tar.gz: erpc-1.9.1/setup.py <==
#!/usr/bin/env python

# Copyright (c) 2016 Freescale Semiconductor, Inc.
# Copyright 2016-2019 NXP
# Copyright 2022 ACRIOS Systems s.r.o.
# All rights reserved.
#
# SPDX-License-Identifier: BSD-3-Clause

from setuptools import setup
from codecs import open
from os import path

ERPC_VERSION = None
here = path.abspath(path.dirname(__file__))

with open(path.join(here, 'README_Pypi.md'), encoding='utf-8') as f:
    long_description = f.read()

with open(path.join(here, 'erpc', 'erpc_version.py')) as f:
    exec(f.read())

#steps: https://packaging.python.org/distributing/
#source distribution: python setup.py sdist
#wheel distribution: python setup.py bdist_wheel
#web: https://pypi.python.org/pypi?%3Aaction=submit_form

setup(
    name="erpc",
    version=ERPC_VERSION,
    description="eRPC Python infrastructure",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="NXP",
    url='https://github.com/embeddedrpc/erpc',
    license="BSD 3-Clause",
    install_requires=[],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved :: BSD License",
        "Programming Language :: Python",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Embedded Systems",
        "Natural Language :: English",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: POSIX :: Linux",
    ],
    keywords='rpc rpc-framework embedded multicore multiprocessor amp rpmsg_lite',
    packages=['erpc'],
)
